@@ -43,14 +43,14 @@ class Migrate(object):
     def __init__(self, app=None, db=None, directory='migrations', **kwargs):
         self.configure_callbacks = []
         self.db = db
-        self.directory = directory
+        self.directory = str(directory)
         self.alembic_ctx_kwargs = kwargs
         if app is not None and db is not None:
             self.init_app(app, db, directory)
 
     def init_app(self, app, db=None, directory=None, **kwargs):
         self.db = db or self.db
-        self.directory = directory or self.directory
+        self.directory = str(directory or self.directory)
         self.alembic_ctx_kwargs.update(kwargs)
         if not hasattr(app, 'extensions'):
             app.extensions = {}
@@ -69,6 +69,7 @@ class Migrate(object):
     def get_config(self, directory=None, x_arg=None, opts=None):
         if directory is None:
             directory = self.directory
+        directory = str(directory)
         config = Config(os.path.join(directory, 'alembic.ini'))
         config.set_main_option('script_location', directory)
         if config.cmd_opts is None:
@@ -112,7 +113,7 @@ else:
 
 
 @MigrateCommand.option('-d', '--directory', dest='directory', default=None,
-                       help=("migration script directory (default is "
+                       help=("Migration script directory (default is "
                              "'migrations')"))
 @MigrateCommand.option('--multidb', dest='multidb', action='store_true',
                        default=False,
@@ -161,7 +162,7 @@ def init(directory=None, multidb=False):
 @MigrateCommand.option('-m', '--message', dest='message', default=None,
                        help='Revision message')
 @MigrateCommand.option('-d', '--directory', dest='directory', default=None,
-                       help=("migration script directory (default is "
+                       help=("Migration script directory (default is "
                              "'migrations')"))
 @catch_errors
 def revision(directory=None, message=None, autogenerate=False, sql=False,
@@ -169,12 +170,9 @@ def revision(directory=None, message=None, autogenerate=False, sql=False,
              rev_id=None):
     """Create a new revision file."""
     config = current_app.extensions['migrate'].migrate.get_config(directory)
-    if alembic_version >= (0, 7, 0):
-        command.revision(config, message, autogenerate=autogenerate, sql=sql,
-                         head=head, splice=splice, branch_label=branch_label,
-                         version_path=version_path, rev_id=rev_id)
-    else:
-        command.revision(config, message, autogenerate=autogenerate, sql=sql)
+    command.revision(config, message, autogenerate=autogenerate, sql=sql,
+                     head=head, splice=splice, branch_label=branch_label,
+                     version_path=version_path, rev_id=rev_id)
 
 
 @MigrateCommand.option('--rev-id', dest='rev_id', default=None,
@@ -198,7 +196,7 @@ def revision(directory=None, message=None, autogenerate=False, sql=False,
                              "output instead"))
 @MigrateCommand.option('-m', '--message', dest='message', default=None)
 @MigrateCommand.option('-d', '--directory', dest='directory', default=None,
-                       help=("migration script directory (default is "
+                       help=("Migration script directory (default is "
                              "'migrations')"))
 @MigrateCommand.option('-x', '--x-arg', dest='x_arg', default=None,
                        action='append', help=("Additional arguments consumed "
@@ -209,18 +207,15 @@ def migrate(directory=None, message=None, sql=False, head='head', splice=False,
     """Alias for 'revision --autogenerate'"""
     config = current_app.extensions['migrate'].migrate.get_config(
         directory, opts=['autogenerate'], x_arg=x_arg)
-    if alembic_version >= (0, 7, 0):
-        command.revision(config, message, autogenerate=True, sql=sql,
-                         head=head, splice=splice, branch_label=branch_label,
-                         version_path=version_path, rev_id=rev_id)
-    else:
-        command.revision(config, message, autogenerate=True, sql=sql)
+    command.revision(config, message, autogenerate=True, sql=sql,
+                     head=head, splice=splice, branch_label=branch_label,
+                     version_path=version_path, rev_id=rev_id)
 
 
 @MigrateCommand.option('revision', nargs='?', default='head',
                        help="revision identifier")
 @MigrateCommand.option('-d', '--directory', dest='directory', default=None,
-                       help=("migration script directory (default is "
+                       help=("Migration script directory (default is "
                              "'migrations')"))
 @catch_errors
 def edit(directory=None, revision='current'):
@@ -243,19 +238,15 @@ def edit(directory=None, revision='current'):
 @MigrateCommand.option('revisions', nargs='+',
                        help='one or more revisions, or "heads" for all heads')
 @MigrateCommand.option('-d', '--directory', dest='directory', default=None,
-                       help=("migration script directory (default is "
+                       help=("Migration script directory (default is "
                              "'migrations')"))
 @catch_errors
 def merge(directory=None, revisions='', message=None, branch_label=None,
           rev_id=None):
     """Merge two revisions together.  Creates a new migration file"""
-    if alembic_version >= (0, 7, 0):
-        config = current_app.extensions['migrate'].migrate.get_config(
-            directory)
-        command.merge(config, revisions, message=message,
-                      branch_label=branch_label, rev_id=rev_id)
-    else:
-        raise RuntimeError('Alembic 0.7.0 or greater is required')
+    config = current_app.extensions['migrate'].migrate.get_config(directory)
+    command.merge(config, revisions, message=message,
+                  branch_label=branch_label, rev_id=rev_id)
 
 
 @MigrateCommand.option('--tag', dest='tag', default=None,
@@ -267,7 +258,7 @@ def merge(directory=None, revisions='', message=None, branch_label=None,
 @MigrateCommand.option('revision', nargs='?', default='head',
                        help="revision identifier")
 @MigrateCommand.option('-d', '--directory', dest='directory', default=None,
-                       help=("migration script directory (default is "
+                       help=("Migration script directory (default is "
                              "'migrations')"))
 @MigrateCommand.option('-x', '--x-arg', dest='x_arg', default=None,
                        action='append', help=("Additional arguments consumed "
@@ -289,7 +280,7 @@ def upgrade(directory=None, revision='head', sql=False, tag=None, x_arg=None):
 @MigrateCommand.option('revision', nargs='?', default="-1",
                        help="revision identifier")
 @MigrateCommand.option('-d', '--directory', dest='directory', default=None,
-                       help=("migration script directory (default is "
+                       help=("Migration script directory (default is "
                              "'migrations')"))
 @MigrateCommand.option('-x', '--x-arg', dest='x_arg', default=None,
                        action='append', help=("Additional arguments consumed "
@@ -307,17 +298,13 @@ def downgrade(directory=None, revision='-1', sql=False, tag=None, x_arg=None):
 @MigrateCommand.option('revision', nargs='?', default="head",
                        help="revision identifier")
 @MigrateCommand.option('-d', '--directory', dest='directory', default=None,
-                       help=("migration script directory (default is "
+                       help=("Migration script directory (default is "
                              "'migrations')"))
 @catch_errors
 def show(directory=None, revision='head'):
     """Show the revision denoted by the given symbol."""
-    if alembic_version >= (0, 7, 0):
-        config = current_app.extensions['migrate'].migrate.get_config(
-            directory)
-        command.show(config, revision)
-    else:
-        raise RuntimeError('Alembic 0.7.0 or greater is required')
+    config = current_app.extensions['migrate'].migrate.get_config(directory)
+    command.show(config, revision)
 
 
 @MigrateCommand.option('-i', '--indicate-current', dest='indicate_current', action='store_true',
@@ -327,7 +314,7 @@ def show(directory=None, revision='head'):
 @MigrateCommand.option('-r', '--rev-range', dest='rev_range', default=None,
                        help='Specify a revision range; format is [start]:[end]')
 @MigrateCommand.option('-d', '--directory', dest='directory', default=None,
-                       help=("migration script directory (default is "
+                       help=("Migration script directory (default is "
                              "'migrations')"))
 @catch_errors
 def history(directory=None, rev_range=None, verbose=False, indicate_current=False):
@@ -335,10 +322,8 @@ def history(directory=None, rev_range=None, verbose=False, indicate_current=Fals
     config = current_app.extensions['migrate'].migrate.get_config(directory)
     if alembic_version >= (0, 9, 9):
         command.history(config, rev_range, verbose=verbose, indicate_current=indicate_current)
-    elif alembic_version >= (0, 7, 0):
-        command.history(config, rev_range, verbose=verbose)
     else:
-        command.history(config, rev_range)
+        command.history(config, rev_range, verbose=verbose)
 
 
 @MigrateCommand.option('--resolve-dependencies', dest='resolve_dependencies',
@@ -347,33 +332,26 @@ def history(directory=None, rev_range=None, verbose=False, indicate_current=Fals
 @MigrateCommand.option('-v', '--verbose', dest='verbose', action='store_true',
                        default=False, help='Use more verbose output')
 @MigrateCommand.option('-d', '--directory', dest='directory', default=None,
-                       help=("migration script directory (default is "
+                       help=("Migration script directory (default is "
                              "'migrations')"))
 @catch_errors
 def heads(directory=None, verbose=False, resolve_dependencies=False):
     """Show current available heads in the script directory"""
-    if alembic_version >= (0, 7, 0):
-        config = current_app.extensions['migrate'].migrate.get_config(
-            directory)
-        command.heads(config, verbose=verbose,
-                      resolve_dependencies=resolve_dependencies)
-    else:
-        raise RuntimeError('Alembic 0.7.0 or greater is required')
+    config = current_app.extensions['migrate'].migrate.get_config(directory)
+    command.heads(config, verbose=verbose,
+                  resolve_dependencies=resolve_dependencies)
 
 
 @MigrateCommand.option('-v', '--verbose', dest='verbose', action='store_true',
                        default=False, help='Use more verbose output')
 @MigrateCommand.option('-d', '--directory', dest='directory', default=None,
-                       help=("migration script directory (default is "
+                       help=("Migration script directory (default is "
                              "'migrations')"))
 @catch_errors
 def branches(directory=None, verbose=False):
     """Show current branch points"""
     config = current_app.extensions['migrate'].migrate.get_config(directory)
-    if alembic_version >= (0, 7, 0):
-        command.branches(config, verbose=verbose)
-    else:
-        command.branches(config)
+    command.branches(config, verbose=verbose)
 
 
 @MigrateCommand.option('--head-only', dest='head_only', action='store_true',
@@ -382,16 +360,13 @@ def branches(directory=None, verbose=False):
 @MigrateCommand.option('-v', '--verbose', dest='verbose', action='store_true',
                        default=False, help='Use more verbose output')
 @MigrateCommand.option('-d', '--directory', dest='directory', default=None,
-                       help=("migration script directory (default is "
+                       help=("Migration script directory (default is "
                              "'migrations')"))
 @catch_errors
 def current(directory=None, verbose=False, head_only=False):
     """Display the current revision for each database."""
     config = current_app.extensions['migrate'].migrate.get_config(directory)
-    if alembic_version >= (0, 7, 0):
-        command.current(config, verbose=verbose, head_only=head_only)
-    else:
-        command.current(config)
+    command.current(config, verbose=verbose, head_only=head_only)
 
 
 @MigrateCommand.option('--tag', dest='tag', default=None,
@@ -402,7 +377,7 @@ def current(directory=None, verbose=False, head_only=False):
                              "output instead"))
 @MigrateCommand.option('revision', default=None, help="revision identifier")
 @MigrateCommand.option('-d', '--directory', dest='directory', default=None,
-                       help=("migration script directory (default is "
+                       help=("Migration script directory (default is "
                              "'migrations')"))
 @catch_errors
 def stamp(directory=None, revision='head', sql=False, tag=None):
